import matplotlib.pyplot as plt
from matplotlib.ticker import ScalarFormatter
import numpy as np
plt.rc('text',usetex=True)
plt.rc('font',family='serif')

# Timeline of pulsar discoveries: [month since launch, total psrs]

# -------------------------------------------------------------------------------------
# By T_obs
# psr_timeline = np.array([[0,0],
#                          [2,1],  # CTA 1
#                          [5,15], # 16 PSRs - CTA1, Abdo et al., 2009
#                          [11,8], # 8 PSRs, Saz Parkinson et al., 2010
#                          [23,2], # 2 PSRs, Saz Parkinson et al., 2010
#                          [32,10], # 9 Pulsars + J1838, Pletsch et al. 2012
#                          [36,4], # 4 E@H Pulsars, 2013
#                          [47,1],  # J1311-3430
#                          [68,10], # First bunch of FGRP4 pulsars - 2 MSPs
#                          [74, 4], # Next bunch of FGRP4 pulsars - J1208
#                          [91, 0]] ) # Now
# FGRP1_idx = 6
# FGRP4_idx = 8

# -------------------------------------------------------------------------------------
# By publication date
psr_timeline = np.array([[0,0],
                         [4,1],  # CTA 1
                         [12,15], # 16 PSRs - CTA1, Abdo et al., 2009
                         [27,8], # 8 PSRs, Saz Parkinson et al., 2010
                         [33,2], # 2 PSRs, Saz Parkinson et al., 2010
                         [39,9], # 9 Pulsars, Pletsch et al. 2012
                         [47,1], # J1838
                         [47,1],  # J1311-3430
                         [64,4], # 4 E@H Pulsars, 2013
                         [84,1], # J1906
                         [91, 13], # Next bunch of FGRP4 pulsars without J1208
                         [100,1], # J1208
                         [106, 2], # J1817, J1641
                         [116,2], # 2 E@H MSPs
                         [117,0]]) 
FGRP1_idx = 8
FGRP4_idx = 9
AEI_idx = 5

# -------------------------------------------------------------------------------------

start = 54682
mjd2008 = 54466

months = 2008 + (psr_timeline[:,0] * (365.25 / 12) + (start - mjd2008))/365.25
psrs = np.cumsum(psr_timeline[:,1])

xfmt = ScalarFormatter(useOffset=False)

fig = plt.figure(figsize=(10,5.5))
ax = fig.add_subplot(111)
plt.step(months, psrs,where='post',color='red',linewidth=2.0)
plt.xticks(np.arange(2009,2019))
plt.ylabel('Total number of pulsars discovered')
plt.title('Timeline of gamma-ray pulsar discoveries in blind searches with Fermi LAT')

ax.xaxis.set_major_formatter(xfmt)
plt.xlim(months[0],months[-1])

# Survey labels
plt.text(months[FGRP1_idx] + 0.8, 33,'E@H\nFGRP1',ha='center')
plt.text(months[AEI_idx] + 1.0, 29,'ATLAS Cluster\n AEI Hannover',ha='center')
plt.text(months[FGRP4_idx] + 1.40, 35,'E@H\nFGRP4',ha='center')

# Survey shading
plt.fill_between(months[FGRP4_idx:],psrs[FGRP4_idx:],color='grey',step='post')
plt.fill_between(months[AEI_idx:FGRP1_idx+1],psrs[AEI_idx:FGRP1_idx+1],color='lightgrey',step='post')
plt.fill_between(months[FGRP1_idx:FGRP1_idx+2],psrs[FGRP1_idx:FGRP1_idx+2],color='darkgrey',step='post')

ax.spines['right'].set_visible(False)
ax.spines['top'].set_visible(False)
ax.xaxis.set_ticks_position('bottom')
ax.yaxis.set_ticks_position('left')
plt.ylim(ymin=0)
plt.savefig('img/psrs_vs_time.png',bbox_inches='tight')
plt.show()

